@@ -232,7 +232,14 @@ GarconMenuNodeType garcon_menu_node_get_node_type (GarconMenuNode *node)
 }
 
 
-
+/**
+ * garcon_menu_node_create:
+ * @node_type: a #GarconMenuNodeType
+ * @first_value:
+ * @...:
+ *
+ * Returns: (transfer full): a #GarconMenuNode
+ */
 GarconMenuNode *
 garcon_menu_node_create (GarconMenuNodeType node_type,
                          gpointer           first_value,
@@ -274,9 +281,16 @@ garcon_menu_node_create (GarconMenuNodeType node_type,
 }
 
 
-
+/**
+ * garcon_menu_node_copy:
+ * @node: a #GarconMenuNode
+ * @data:
+ *
+ * Returns: (transfer full): a #GarconMenuNode
+ */
 GarconMenuNode *
-garcon_menu_node_copy (GarconMenuNode *node)
+garcon_menu_node_copy (GarconMenuNode *node,
+                       gpointer        data)
 {
   GarconMenuNode *copy;
 
@@ -420,7 +434,6 @@ typedef struct
 {
   GarconMenuNodeType type;
   GNode             *self;
-  gboolean           reverse;
   gpointer           value;
 } Pair;
 
@@ -434,39 +447,60 @@ collect_children (GNode *node,
     return FALSE;
 
   if (garcon_menu_node_tree_get_node_type (node) == pair->type)
-    {
-      if (pair->reverse)
-        pair->value = g_list_prepend (pair->value, node);
-      else
-        pair->value = g_list_append (pair->value, node);
-    }
+    pair->value = g_list_prepend (pair->value, node);
 
   return FALSE;
 }
 
 
-
+/**
+ * garcon_menu_node_tree_get_child_node: (skip)
+ * @tree: #GNode instance
+ * @type: type for the menu nodes
+ * @reverse:
+ *
+ * Returns: a #GNode if @type is valid menu nodes type.
+ */
 GNode *
 garcon_menu_node_tree_get_child_node (GNode             *tree,
                                       GarconMenuNodeType type,
                                       gboolean           reverse)
 {
-  GNode *node = NULL;
-  GNode *child;
+  GNode *child = NULL;
 
-  for (child = reverse ? g_node_last_child (tree) : g_node_first_child (tree);
-       node == NULL && child != NULL;
-       child = reverse ? g_node_prev_sibling (child) : g_node_next_sibling (child))
+  if (reverse)
     {
-      if (garcon_menu_node_tree_get_node_type (child) == type)
-        node = child;
+      for (child = g_node_last_child (tree); 
+           child != NULL;
+           child = g_node_prev_sibling (child))
+        {
+          if (garcon_menu_node_tree_get_node_type (child) == type)
+            return child;
+        }
+    }
+  else
+    {
+      for (child = g_node_first_child (tree);
+           child != NULL;
+           child = g_node_next_sibling (child))
+        {
+          if (garcon_menu_node_tree_get_node_type (child) == type)
+            return child;
+        }
     }
 
-  return node;
+  return child;
 }
 
 
-
+/**
+ * garcon_menu_node_tree_get_child_nodes:
+ * @tree: a GNode
+ * @type: type for the menu nodes
+ * @reverse:
+ *
+ * Returns: (element-type GNode) (transfer full): list of #GNode
+ */
 GList *
 garcon_menu_node_tree_get_child_nodes (GNode             *tree,
                                        GarconMenuNodeType type,
@@ -475,14 +509,17 @@ garcon_menu_node_tree_get_child_nodes (GNode             *tree,
   Pair pair;
 
   pair.type = type;
-  pair.reverse = reverse;
   pair.value = NULL;
   pair.self = tree;
 
   g_node_traverse (tree, G_IN_ORDER, G_TRAVERSE_ALL, 2,
                    (GNodeTraverseFunc) collect_children, &pair);
 
-  return pair.value;
+  /* Return the list as if we appended */
+  if (!reverse && pair.value != NULL)
+    pair.value = g_list_reverse (pair.value);
+
+  return (GList *) pair.value;
 }
 
 
@@ -499,18 +536,21 @@ collect_strings (GNode *node,
   if (garcon_menu_node_tree_get_node_type (node) == pair->type)
     {
       string = (gpointer) garcon_menu_node_tree_get_string (node);
-
-      if (pair->reverse)
-        pair->value = g_list_prepend (pair->value, string);
-      else
-        pair->value = g_list_append (pair->value, string);
+      pair->value = g_list_prepend (pair->value, string);
     }
 
   return FALSE;
 }
 
 
-
+/**
+ * garcon_menu_node_tree_get_string_children:
+ * @tree: a #GNode instance
+ * @type: type for the menu nodes
+ * @reverse:
+ *
+ * Returns: (element-type GNode) (transfer full): list of #GNode
+ */
 GList *
 garcon_menu_node_tree_get_string_children (GNode             *tree,
                                            GarconMenuNodeType type,
@@ -519,14 +559,17 @@ garcon_menu_node_tree_get_string_children (GNode             *tree,
   Pair pair;
 
   pair.type = type;
-  pair.reverse = reverse;
   pair.value = NULL;
   pair.self = tree;
 
   g_node_traverse (tree, G_IN_ORDER, G_TRAVERSE_ALL, 2,
                    (GNodeTraverseFunc) collect_strings, &pair);
 
-  return pair.value;
+  /* Return the list as if we appended */
+  if (!reverse && pair.value != NULL)
+    pair.value = g_list_reverse (pair.value);
+
+  return (GList *) pair.value;
 }
 
 
@@ -616,6 +659,10 @@ garcon_menu_node_tree_rule_matches (GNode          *node,
 
   switch (garcon_menu_node_tree_get_node_type (node))
     {
+    case GARCON_MENU_NODE_TYPE_CATEGORY:
+      matches = garcon_menu_item_has_category (item, garcon_menu_node_tree_get_string (node));
+      break;
+
     case GARCON_MENU_NODE_TYPE_INCLUDE:
     case GARCON_MENU_NODE_TYPE_EXCLUDE:
     case GARCON_MENU_NODE_TYPE_OR:
@@ -623,6 +670,11 @@ garcon_menu_node_tree_rule_matches (GNode          *node,
         matches = matches || garcon_menu_node_tree_rule_matches (child, item);
       break;
 
+    case GARCON_MENU_NODE_TYPE_FILENAME:
+      matches = g_str_equal (garcon_menu_node_tree_get_string (node),
+                             garcon_menu_item_get_desktop_id (item));
+      break;
+
     case GARCON_MENU_NODE_TYPE_AND:
       matches = TRUE;
       for (child = g_node_first_child (node); child != NULL; child = g_node_next_sibling (child))
@@ -635,15 +687,6 @@ garcon_menu_node_tree_rule_matches (GNode          *node,
       matches = !child_matches;
       break;
 
-    case GARCON_MENU_NODE_TYPE_FILENAME:
-      matches = g_str_equal (garcon_menu_node_tree_get_string (node),
-                             garcon_menu_item_get_desktop_id (item));
-      break;
-
-    case GARCON_MENU_NODE_TYPE_CATEGORY:
-      matches = garcon_menu_item_has_category (item, garcon_menu_node_tree_get_string (node));
-      break;
-
     case GARCON_MENU_NODE_TYPE_ALL:
       matches = TRUE;
       break;
@@ -790,7 +833,12 @@ garcon_menu_node_tree_compare (GNode *tree,
 }
 
 
-
+/**
+ * garcon_menu_node_tree_copy: (skip)
+ * @tree: a #GNode
+ *
+ * Recursively copies a #GNode.
+ */
 GNode *
 garcon_menu_node_tree_copy (GNode *tree)
 {
@@ -800,7 +848,8 @@ garcon_menu_node_tree_copy (GNode *tree)
 
 
 static gboolean
-free_children (GNode *tree)
+free_children (GNode   *tree,
+               gpointer data)
 {
   garcon_menu_node_tree_free_data (tree);
   return FALSE;
