@@ -49,11 +49,7 @@ show_menu (GtkButton *button,
            GtkWidget *menu)
 {
   /* Display the menu */
-#if GTK_CHECK_VERSION (3, 22, 0)
   gtk_menu_popup_at_widget (GTK_MENU (menu), GTK_WIDGET (button), GDK_GRAVITY_EAST, GDK_GRAVITY_SOUTH, gtk_get_current_event ());
-#else
-  gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
-#endif
 }
 
 
@@ -129,11 +125,7 @@ create_main_window (void)
   g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (main_window_destroy), NULL);
 
   /* Create the box to hold all the stuff */
-#if GTK_CHECK_VERSION (3, 0, 0)
   box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-#else
-  box = gtk_vbox_new (FALSE, 0);
-#endif
   gtk_container_add (GTK_CONTAINER (window), box);
   gtk_widget_show (box);
 
