@@ -222,16 +222,6 @@ main (int    argc,
   gchar            *relative_filename;
   gint              result = EXIT_SUCCESS;
 
-#if !GLIB_CHECK_VERSION (2, 36, 0)
-  /* Initialize the type system */
-  g_type_init ();
-#endif
-
-#if !GLIB_CHECK_VERSION(2,32,0)
-  if (!g_thread_supported ())
-    g_thread_init (NULL);
-#endif
-
   garcon_set_environment ("XFCE");
 
   if (argc > 1)
